import type { Buffer } from 'node:buffer';

export declare interface AAXConfig {
  verbose: boolean
  outputDir?: string
  outputFormat?: 'mp3' | 'm4a' | 'm4b'
  chaptersEnabled?: boolean
  bitrate?: number | 'source'
  ffmpegPath?: string
  activationCode?: string

  flatFolderStructure?: boolean
  seriesTitleInFolderStructure?: boolean
  fullCaptionForBookFolder?: boolean
  partFolderPrefix?: string
  sequenceNumberDigits?: number

  customSearchWords?: string[]
  additionalPunctuation?: string
  intermediateFileCopy?: boolean
  aacEncoding44_1?: boolean
  variableBitRate?: boolean
  reduceBitRate?: 'no' | 'auto' | 'manual'
  fileType?: 'm4a' | 'm4b'
  useISOLatin1?: boolean
  extractCoverImage?: boolean

  useNamedChapters?: boolean
  skipShortChaptersDuration?: number
  skipVeryShortChapterDuration?: number
  verifyChapterMarks?: 'all' | 'none' | 'selected'
  preferEmbeddedChapterTimes?: boolean
}
export declare interface ConversionOptions extends Partial<AAXConfig> {
  inputFile: string
}
export declare interface ConversionResult {
  success: boolean
  outputPath?: string
  error?: string
}
export declare interface FileNaming {
  pattern: string
  titlePattern: string
  trackNumberingPattern: string
  addTotalTracks: boolean
  genreNaming: string
  customGenre?: string
  chapterFolderPrefix?: string
  customChapterFolder?: string
  seriesTitleSuffix?: boolean
  longBookTitle?: boolean
}
export declare interface BookMetadata {
  title?: string
  author?: string
  narrator?: string
  duration?: number
  chapters?: Chapter[]
  series?: string
  seriesIndex?: number
  publishingYear?: number
  publisher?: string
  copyright?: string
  description?: string
  coverImage?: Buffer
}
export declare interface Chapter {
  title: string
  startTime: number
  endTime: number
}